import sys
import typing
import bl_ui.space_toolsystem_common
import bpy_types

GenericType = typing.TypeVar("GenericType")


class IMAGE_PT_tools_active(
        bl_ui.space_toolsystem_common.ToolSelectPanelHelper, bpy_types.Panel,
        bpy_types._GenericUI):
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any
    keymap_prefix: typing.Any
    tool_fallback_id: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_active_tool_fallback(self, context, layout, tool,
                                  is_horizontal_layout):
        ...

    def draw_active_tool_header(self, context, layout, show_tool_icon_always,
                                tool_key):
        ...

    def draw_cls(self, layout, context, detect_layout, scale_y):
        ...

    def draw_fallback_tool_items(self, layout, context):
        ...

    def draw_fallback_tool_items_for_pie_menu(self, layout, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keymap_ui_hierarchy(self, context_mode):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def register(self):
        ...

    def register_ensure(self):
        ...

    def remove(self, draw_func):
        ...

    def tool_active_from_context(self, context):
        ...

    def tools_all(self):
        ...

    def tools_from_context(self, context, mode):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_PT_tools_active(bl_ui.space_toolsystem_common.ToolSelectPanelHelper,
                           bpy_types.Panel, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any
    keymap_prefix: typing.Any
    tool_fallback_id: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_active_tool_fallback(self, context, layout, tool,
                                  is_horizontal_layout):
        ...

    def draw_active_tool_header(self, context, layout, show_tool_icon_always,
                                tool_key):
        ...

    def draw_cls(self, layout, context, detect_layout, scale_y):
        ...

    def draw_fallback_tool_items(self, layout, context):
        ...

    def draw_fallback_tool_items_for_pie_menu(self, layout, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keymap_ui_hierarchy(self, context_mode):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def register(self):
        ...

    def register_ensure(self):
        ...

    def remove(self, draw_func):
        ...

    def tool_active_from_context(self, context):
        ...

    def tools_all(self):
        ...

    def tools_from_context(self, context, mode):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class SEQUENCER_PT_tools_active(
        bl_ui.space_toolsystem_common.ToolSelectPanelHelper, bpy_types.Panel,
        bpy_types._GenericUI):
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any
    keymap_prefix: typing.Any
    tool_fallback_id: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_active_tool_fallback(self, context, layout, tool,
                                  is_horizontal_layout):
        ...

    def draw_active_tool_header(self, context, layout, show_tool_icon_always,
                                tool_key):
        ...

    def draw_cls(self, layout, context, detect_layout, scale_y):
        ...

    def draw_fallback_tool_items(self, layout, context):
        ...

    def draw_fallback_tool_items_for_pie_menu(self, layout, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keymap_ui_hierarchy(self, context_mode):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def register(self):
        ...

    def register_ensure(self):
        ...

    def remove(self, draw_func):
        ...

    def tool_active_from_context(self, context):
        ...

    def tools_all(self):
        ...

    def tools_from_context(self, context, mode):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class VIEW3D_PT_tools_active(
        bl_ui.space_toolsystem_common.ToolSelectPanelHelper, bpy_types.Panel,
        bpy_types._GenericUI):
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any
    keymap_prefix: typing.Any
    tool_fallback_id: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_active_tool_fallback(self, context, layout, tool,
                                  is_horizontal_layout):
        ...

    def draw_active_tool_header(self, context, layout, show_tool_icon_always,
                                tool_key):
        ...

    def draw_cls(self, layout, context, detect_layout, scale_y):
        ...

    def draw_fallback_tool_items(self, layout, context):
        ...

    def draw_fallback_tool_items_for_pie_menu(self, layout, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keymap_ui_hierarchy(self, context_mode):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def register(self):
        ...

    def register_ensure(self):
        ...

    def remove(self, draw_func):
        ...

    def tool_active_from_context(self, context):
        ...

    def tools_all(self):
        ...

    def tools_from_context(self, context, mode):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class _defs_annotate:
    eraser: typing.Any
    line: typing.Any
    poly: typing.Any
    scribble: typing.Any

    def draw_settings_common(self, context, layout, tool):
        ...


class _defs_curves_sculpt:
    def generate_from_brushes(self, context):
        ...


class _defs_edit_armature:
    bone_envelope: typing.Any
    bone_size: typing.Any
    extrude: typing.Any
    extrude_cursor: typing.Any
    roll: typing.Any


class _defs_edit_curve:
    curve_radius: typing.Any
    curve_vertex_randomize: typing.Any
    draw: typing.Any
    extrude: typing.Any
    extrude_cursor: typing.Any
    pen: typing.Any
    tilt: typing.Any


class _defs_edit_curves:
    draw: typing.Any


class _defs_edit_mesh:
    bevel: typing.Any
    bisect: typing.Any
    edge_slide: typing.Any
    extrude: typing.Any
    extrude_cursor: typing.Any
    extrude_individual: typing.Any
    extrude_manifold: typing.Any
    extrude_normals: typing.Any
    inset: typing.Any
    knife: typing.Any
    loopcut_slide: typing.Any
    offset_edge_loops_slide: typing.Any
    poly_build: typing.Any
    push_pull: typing.Any
    rip_edge: typing.Any
    rip_region: typing.Any
    shrink_fatten: typing.Any
    spin: typing.Any
    spin_duplicate: typing.Any
    tosphere: typing.Any
    vert_slide: typing.Any
    vertex_randomize: typing.Any
    vertex_smooth: typing.Any


class _defs_edit_text:
    select_text: typing.Any


class _defs_gpencil_edit:
    bend: typing.Any
    box_select: typing.Any
    circle_select: typing.Any
    extrude: typing.Any
    interpolate: typing.Any
    lasso_select: typing.Any
    radius: typing.Any
    select: typing.Any
    shear: typing.Any
    tosphere: typing.Any
    transform_fill: typing.Any

    def is_segment(self, context):
        ...


class _defs_gpencil_paint:
    arc: typing.Any
    box: typing.Any
    circle: typing.Any
    curve: typing.Any
    cutter: typing.Any
    eyedropper: typing.Any
    interpolate: typing.Any
    line: typing.Any
    polyline: typing.Any

    def generate_from_brushes(self, context):
        ...

    def gpencil_primitive_toolbar(self, context, layout, _tool, props):
        ...


class _defs_gpencil_sculpt:
    def generate_from_brushes(self, context):
        ...

    def poll_select_mask(self, context):
        ...


class _defs_gpencil_vertex:
    def generate_from_brushes(self, context):
        ...

    def poll_select_mask(self, context):
        ...


class _defs_gpencil_weight:
    def generate_from_brushes(self, context):
        ...


class _defs_image_generic:
    cursor: typing.Any
    sample: typing.Any

    def poll_uvedit(self, context):
        ...


class _defs_image_uv_edit:
    rip_region: typing.Any


class _defs_image_uv_sculpt:
    def generate_from_brushes(self, context):
        ...


class _defs_image_uv_select:
    box: typing.Any
    circle: typing.Any
    lasso: typing.Any
    select: typing.Any


class _defs_image_uv_transform:
    rotate: typing.Any
    scale: typing.Any
    transform: typing.Any
    translate: typing.Any


class _defs_node_edit:
    links_cut: typing.Any


class _defs_node_select:
    box: typing.Any
    circle: typing.Any
    lasso: typing.Any
    select: typing.Any


class _defs_paint_grease_pencil:
    draw: typing.Any
    erase: typing.Any


class _defs_particle:
    def generate_from_brushes(self, context):
        ...


class _defs_pose:
    breakdown: typing.Any
    push: typing.Any
    relax: typing.Any


class _defs_sculpt:
    cloth_filter: typing.Any
    color_filter: typing.Any
    face_set_box: typing.Any
    face_set_edit: typing.Any
    face_set_lasso: typing.Any
    hide_border: typing.Any
    mask_border: typing.Any
    mask_by_color: typing.Any
    mask_lasso: typing.Any
    mask_line: typing.Any
    mesh_filter: typing.Any
    project_line: typing.Any
    trim_box: typing.Any
    trim_lasso: typing.Any

    def generate_from_brushes(self, context):
        ...


class _defs_sequencer_generic:
    blade: typing.Any
    cursor: typing.Any
    rotate: typing.Any
    sample: typing.Any
    scale: typing.Any
    transform: typing.Any
    translate: typing.Any


class _defs_sequencer_select:
    box: typing.Any
    select: typing.Any


class _defs_texture_paint:
    def generate_from_brushes(self, context):
        ...

    def poll_select_mask(self, context):
        ...


class _defs_transform:
    bend: typing.Any
    rotate: typing.Any
    scale: typing.Any
    scale_cage: typing.Any
    shear: typing.Any
    transform: typing.Any
    translate: typing.Any

    def draw_transform_sculpt_tool_settings(self, context, layout):
        ...


class _defs_vertex_paint:
    def generate_from_brushes(self, context):
        ...

    def poll_select_mask(self, context):
        ...


class _defs_view3d_add:
    cone_add: typing.Any
    cube_add: typing.Any
    cylinder_add: typing.Any
    ico_sphere_add: typing.Any
    uv_sphere_add: typing.Any

    def description_interactive_add(self, context, _item, _km, prefix):
        ...

    def draw_settings_interactive_add(self, layout, tool_settings, tool,
                                      extra):
        ...


class _defs_view3d_generic:
    cursor: typing.Any
    cursor_click: typing.Any
    ruler: typing.Any


class _defs_view3d_select:
    box: typing.Any
    circle: typing.Any
    lasso: typing.Any
    select: typing.Any


class _defs_weight_paint:
    gradient: typing.Any
    sample_weight: typing.Any
    sample_weight_group: typing.Any

    def generate_from_brushes(self, context):
        ...

    def poll_select_tools(self, context):
        ...


class _template_widget:
    def VIEW3D_GGT_xform_extrude(self):
        ...

    def VIEW3D_GGT_xform_gizmo(self):
        ...


def curve_draw_settings(context, layout, _tool, extra):
    ...


def generate_from_enum_ex(_context, idname_prefix, icon_prefix, type, attr,
                          cursor, tooldef_keywords, icon_map, use_separators):
    ...


def kmi_to_string_or_none(kmi):
    ...



import sys
import typing
import nodeitems_utils

GenericType = typing.TypeVar("GenericType")


class SortedNodeCategory(nodeitems_utils.NodeCategory):
    def poll(self, _context):
        ...


class CompositorNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
    def poll(self, context):
        ...


class ShaderNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
    def poll(self, context):
        ...


def group_input_output_item_poll(context):
    ...


def group_tools_draw(_self, layout, _context):
    ...


def node_group_items(context):
    ...


def register():
    ...


def unregister():
    ...



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def execute_preset(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        filepath: typing.Union[str, typing.Any] = "",
        menu_idname: typing.Union[str, typing.Any] = ""):
    ''' Load a preset :File: `startup/bl_operators/presets.py\:233 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/presets.py#L233>`__

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param filepath: filepath
    :type filepath: typing.Union[str, typing.Any]
    :param menu_idname: Menu ID Name, ID name of the menu this was called from
    :type menu_idname: typing.Union[str, typing.Any]
    '''

    ...


def python_file_run(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        filepath: typing.Union[str, typing.Any] = ""):
    ''' Run Python file

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param filepath: Path
    :type filepath: typing.Union[str, typing.Any]
    '''

    ...


def reload(override_context: typing.Optional[
        typing.Union[typing.Dict, 'bpy.types.Context']] = None,
           execution_context: typing.Optional[typing.Union[str, int]] = None,
           undo: typing.Optional[bool] = None):
    ''' Reload scripts

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...



import sys
import typing
import freestyle.types

GenericType = typing.TypeVar("GenericType")


class ChainPredicateIterator:
    ''' Class hierarchy: `freestyle.types.Iterator` > `freestyle.types.ViewEdgeIterator` > `freestyle.types.ChainingIterator` > `ChainPredicateIterator` A "generic" user-controlled ViewEdge iterator. This iterator is in particular built from a unary predicate and a binary predicate. First, the unary predicate is evaluated for all potential next ViewEdges in order to only keep the ones respecting a certain constraint. Then, the binary predicate is evaluated on the current ViewEdge together with each ViewEdge of the previous selection. The first ViewEdge respecting both the unary predicate and the binary predicate is kept as the next one. If none of the potential next ViewEdge respects these two predicates, None is returned.
    '''

    def __init__(self,
                 upred: 'freestyle.types.UnaryPredicate1D',
                 bpred: 'freestyle.types.BinaryPredicate1D',
                 restrict_to_selection: bool = True,
                 restrict_to_unvisited: bool = True,
                 begin: typing.Optional['freestyle.types.ViewEdge'] = None,
                 orientation: bool = True):
        ''' __init__(brother) Builds a ChainPredicateIterator from a unary predicate, a binary predicate, a starting ViewEdge and its orientation or using the copy constructor.

        :param upred: The unary predicate that the next ViewEdge must satisfy.
        :type upred: 'freestyle.types.UnaryPredicate1D'
        :param bpred: The binary predicate that the next ViewEdge must satisfy together with the actual pointed ViewEdge.
        :type bpred: 'freestyle.types.BinaryPredicate1D'
        :param restrict_to_selection: Indicates whether to force the chaining to stay within the set of selected ViewEdges or not.
        :type restrict_to_selection: bool
        :param restrict_to_unvisited: Indicates whether a ViewEdge that has already been chained must be ignored ot not.
        :type restrict_to_unvisited: bool
        :param begin: The ViewEdge from where to start the iteration.
        :type begin: typing.Optional['freestyle.types.ViewEdge']
        :param orientation: If true, we'll look for the next ViewEdge among the ViewEdges that surround the ending ViewVertex of begin. If false, we'll search over the ViewEdges surrounding the ending ViewVertex of begin.
        :type orientation: bool
        :param brother: A ChainPredicateIterator object.
        :type brother: 'ChainPredicateIterator'
        '''
        ...


class ChainSilhouetteIterator:
    ''' Class hierarchy: `freestyle.types.Iterator` > `freestyle.types.ViewEdgeIterator` > `freestyle.types.ChainingIterator` > `ChainSilhouetteIterator` A ViewEdge Iterator used to follow ViewEdges the most naturally. For example, it will follow visible ViewEdges of same nature. As soon, as the nature or the visibility changes, the iteration stops (by setting the pointed ViewEdge to 0). In the case of an iteration over a set of ViewEdge that are both Silhouette and Crease, there will be a precedence of the silhouette over the crease criterion.
    '''

    def __init__(self,
                 restrict_to_selection: bool = True,
                 begin: typing.Optional['freestyle.types.ViewEdge'] = None,
                 orientation: bool = True):
        ''' __init__(brother) Builds a ChainSilhouetteIterator from the first ViewEdge used for iteration and its orientation or the copy constructor.

        :param restrict_to_selection: Indicates whether to force the chaining to stay within the set of selected ViewEdges or not.
        :type restrict_to_selection: bool
        :param begin: The ViewEdge from where to start the iteration.
        :type begin: typing.Optional['freestyle.types.ViewEdge']
        :param orientation: If true, we'll look for the next ViewEdge among the ViewEdges that surround the ending ViewVertex of begin. If false, we'll search over the ViewEdges surrounding the ending ViewVertex of begin.
        :type orientation: bool
        :param brother: A ChainSilhouetteIterator object.
        :type brother: 'ChainSilhouetteIterator'
        '''
        ...


class pyChainSilhouetteGenericIterator:
    ''' Natural chaining iterator that follows the edges of the same nature following the topology of objects, with decreasing priority for silhouettes, then borders, then suggestive contours, then all other edge types.
    '''

    def __init__(self,
                 stayInSelection: bool = True,
                 stayInUnvisited: bool = True):
        ''' Builds a pyChainSilhouetteGenericIterator object.

        :param stayInSelection: True if it is allowed to go out of the selection
        :type stayInSelection: bool
        :param stayInUnvisited: May the same ViewEdge be chained twice
        :type stayInUnvisited: bool
        '''
        ...

    def init(self):
        ...

    def traverse(self, iter):
        ...


class pyChainSilhouetteIterator:
    ''' Natural chaining iterator that follows the edges of the same nature following the topology of objects, with decreasing priority for silhouettes, then borders, then suggestive contours, then all other edge types. A ViewEdge is only chained once.
    '''

    def init(self):
        ...

    def traverse(self, iter):
        ...


class pyExternalContourChainingIterator:
    ''' Chains by external contour
    '''

    def checkViewEdge(self, ve, orientation):
        ...

    def init(self):
        ...

    def traverse(self, iter):
        ...


class pyFillOcclusionsAbsoluteAndRelativeChainingIterator:
    ''' Chaining iterator that fills small occlusions regardless of the selection.
    '''

    def __init__(self, percent: float, l: float):
        ''' Builds a pyFillOcclusionsAbsoluteAndRelativeChainingIterator object.

        :param percent: The maximal length of the occluded part as a percentage of the total chain length.
        :type percent: float
        :param l: Absolute length.
        :type l: float
        '''
        ...

    def init(self):
        ...

    def traverse(self, iter):
        ...


class pyFillOcclusionsAbsoluteChainingIterator:
    ''' Chaining iterator that fills small occlusions
    '''

    def __init__(self, length: int):
        ''' Builds a pyFillOcclusionsAbsoluteChainingIterator object.

        :param length: The maximum length of the occluded part in pixels.
        :type length: int
        '''
        ...

    def init(self):
        ...

    def traverse(self, iter):
        ...


class pyFillOcclusionsRelativeChainingIterator:
    ''' Chaining iterator that fills small occlusions
    '''

    def __init__(self, percent: float):
        ''' Builds a pyFillOcclusionsRelativeChainingIterator object.

        :param percent: The maximal length of the occluded part, expressed in a percentage of the total chain length.
        :type percent: float
        '''
        ...

    def init(self):
        ...

    def traverse(self, iter):
        ...


class pyFillQi0AbsoluteAndRelativeChainingIterator:
    ''' Chaining iterator that fills small occlusions regardless of the selection.
    '''

    def __init__(self, percent: float, l: float):
        ''' Builds a pyFillQi0AbsoluteAndRelativeChainingIterator object.

        :param percent: The maximal length of the occluded part as a percentage of the total chain length.
        :type percent: float
        :param l: Absolute length.
        :type l: float
        '''
        ...

    def init(self):
        ...

    def traverse(self, iter):
        ...


class pyNoIdChainSilhouetteIterator:
    ''' Natural chaining iterator that follows the edges of the same nature following the topology of objects, with decreasing priority for silhouettes, then borders, then suggestive contours, then all other edge types. It won't chain the same ViewEdge twice.
    '''

    def __init__(self, stayInSelection: bool = True):
        ''' Builds a pyNoIdChainSilhouetteIterator object.

        :param stayInSelection: True if it is allowed to go out of the selection
        :type stayInSelection: bool
        '''
        ...

    def init(self):
        ...

    def traverse(self, iter):
        ...


class pySketchyChainSilhouetteIterator:
    ''' Natural chaining iterator with a sketchy multiple touch. It chains the same ViewEdge multiple times to achieve a sketchy effect.
    '''

    def __init__(self, nRounds: int = 3, stayInSelection: bool = True):
        ''' Builds a pySketchyChainSilhouetteIterator object.

        :param nRounds: Number of times every Viewedge is chained.
        :type nRounds: int
        :param stayInSelection: if False, edges outside of the selection can be chained.
        :type stayInSelection: bool
        '''
        ...

    def init(self):
        ...

    def make_sketchy(self, ve):
        ''' Creates the sketchy effect by causing the chain to run from the start again. (loop over itself again)

        '''
        ...

    def traverse(self, iter):
        ...


class pySketchyChainingIterator:
    ''' Chaining iterator designed for sketchy style. It chains the same ViewEdge several times in order to produce multiple strokes per ViewEdge.
    '''

    def init(self):
        ...

    def traverse(self, iter):
        ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


def addon_keymap_register(keymap_data):
    ''' Register a set of keymaps for addons using a list of keymaps. See 'blender_defaults.py' for examples of the format this takes.

    '''

    ...


def addon_keymap_unregister(keymap_data):
    ''' Unregister a set of keymaps for addons.

    '''

    ...


def keyconfig_test(kc):
    ...



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def create(override_context: typing.Optional[
        typing.Union[typing.Dict, 'bpy.types.Context']] = None,
           execution_context: typing.Optional[typing.Union[str, int]] = None,
           undo: typing.Optional[bool] = None,
           *,
           name: typing.Union[str, typing.Any] = "Collection"):
    ''' Create an object collection from selected objects

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param name: Name, Name of the new collection
    :type name: typing.Union[str, typing.Any]
    '''

    ...


def objects_add_active(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        collection: typing.Optional[typing.Union[str, int, typing.Any]] = ''):
    ''' Add the object to an object collection that contains the active object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param collection: Collection, The collection to add other selected objects to
    :type collection: typing.Optional[typing.Union[str, int, typing.Any]]
    '''

    ...


def objects_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        collection: typing.Optional[typing.Union[str, int, typing.Any]] = ''):
    ''' Remove selected objects from a collection

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param collection: Collection, The collection to remove this object from
    :type collection: typing.Optional[typing.Union[str, int, typing.Any]]
    '''

    ...


def objects_remove_active(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        collection: typing.Optional[typing.Union[str, int, typing.Any]] = ''):
    ''' Remove the object from an object collection that contains the active object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param collection: Collection, The collection to remove other selected objects from
    :type collection: typing.Optional[typing.Union[str, int, typing.Any]]
    '''

    ...


def objects_remove_all(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Remove selected objects from all collections

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


def complete(line, cursor, namespace):
    ...


def get_argspec(func, strip_self, doc, source):
    ...


def get_doc(obj):
    ...


def reduce_newlines(text):
    ...


def reduce_spaces(text):
    ...



import sys
import typing
import freestyle.types

GenericType = typing.TypeVar("GenericType")


class AndBP1D:
    ...


class AndUP1D:
    ...


class ContourUP1D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `ContourUP1D`
    '''

    def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
        ''' Returns true if the Interface1D is a contour. An Interface1D is a contour if it is bordered by a different shape on each of its sides.

        :param inter: An Interface1D object.
        :type inter: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True if the Interface1D is a contour, false otherwise.
        '''
        ...


class DensityLowerThanUP1D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `DensityLowerThanUP1D`
    '''

    def __init__(self, threshold: float, sigma: float = 2.0):
        ''' Builds a DensityLowerThanUP1D object.

        :param threshold: The value of the threshold density. Any Interface1D having a density lower than this threshold will match.
        :type threshold: float
        :param sigma: The sigma value defining the density evaluation window size used in the `freestyle.functions.DensityF0D` functor.
        :type sigma: float
        '''
        ...

    def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
        ''' Returns true if the density evaluated for the Interface1D is less than a user-defined density value.

        :param inter: An Interface1D object.
        :type inter: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True if the density is lower than a threshold.
        '''
        ...


class EqualToChainingTimeStampUP1D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `freestyle.types.EqualToChainingTimeStampUP1D`
    '''

    def __init__(self, ts: int):
        ''' Builds a EqualToChainingTimeStampUP1D object.

        :param ts: A time stamp value.
        :type ts: int
        '''
        ...

    def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
        ''' Returns true if the Interface1D's time stamp is equal to a certain user-defined value.

        :param inter: An Interface1D object.
        :type inter: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True if the time stamp is equal to a user-defined value.
        '''
        ...


class EqualToTimeStampUP1D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `EqualToTimeStampUP1D`
    '''

    def __init__(self, ts: int):
        ''' Builds a EqualToTimeStampUP1D object.

        :param ts: A time stamp value.
        :type ts: int
        '''
        ...

    def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
        ''' Returns true if the Interface1D's time stamp is equal to a certain user-defined value.

        :param inter: An Interface1D object.
        :type inter: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True if the time stamp is equal to a user-defined value.
        '''
        ...


class ExternalContourUP1D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `ExternalContourUP1D`
    '''

    def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
        ''' Returns true if the Interface1D is an external contour. An Interface1D is an external contour if it is bordered by no shape on one of its sides.

        :param inter: An Interface1D object.
        :type inter: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True if the Interface1D is an external contour, false otherwise.
        '''
        ...


class FalseBP1D:
    ''' Class hierarchy: `freestyle.types.BinaryPredicate1D` > `FalseBP1D`
    '''

    def __call__(self, inter1: 'freestyle.types.Interface1D',
                 inter2: 'freestyle.types.Interface1D') -> bool:
        ''' Always returns false.

        :param inter1: The first Interface1D object.
        :type inter1: 'freestyle.types.Interface1D'
        :param inter2: The second Interface1D object.
        :type inter2: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: False.
        '''
        ...


class FalseUP0D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate0D` > `FalseUP0D`
    '''

    def __call__(self, it: 'freestyle.types.Interface0DIterator') -> bool:
        ''' Always returns false.

        :param it: An Interface0DIterator object.
        :type it: 'freestyle.types.Interface0DIterator'
        :rtype: bool
        :return: False.
        '''
        ...


class FalseUP1D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `FalseUP1D`
    '''

    def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
        ''' Always returns false.

        :param inter: An Interface1D object.
        :type inter: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: False.
        '''
        ...


class Length2DBP1D:
    ''' Class hierarchy: `freestyle.types.BinaryPredicate1D` > `Length2DBP1D`
    '''

    def __call__(self, inter1: 'freestyle.types.Interface1D',
                 inter2: 'freestyle.types.Interface1D') -> bool:
        ''' Returns true if the 2D length of inter1 is less than the 2D length of inter2.

        :param inter1: The first Interface1D object.
        :type inter1: 'freestyle.types.Interface1D'
        :param inter2: The second Interface1D object.
        :type inter2: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True or false.
        '''
        ...


class MaterialBP1D:
    ''' Checks whether the two supplied ViewEdges have the same material.
    '''

    ...


class NotBP1D:
    ...


class NotUP1D:
    ...


class ObjectNamesUP1D:
    ...


class OrBP1D:
    ...


class OrUP1D:
    ...


class QuantitativeInvisibilityRangeUP1D:
    ...


class QuantitativeInvisibilityUP1D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `QuantitativeInvisibilityUP1D`
    '''

    def __init__(self, qi: int = 0):
        ''' Builds a QuantitativeInvisibilityUP1D object.

        :param qi: The Quantitative Invisibility you want the Interface1D to have.
        :type qi: int
        '''
        ...

    def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
        ''' Returns true if the Quantitative Invisibility evaluated at an Interface1D, using the `freestyle.functions.QuantitativeInvisibilityF1D` functor, equals a certain user-defined value.

        :param inter: An Interface1D object.
        :type inter: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True if Quantitative Invisibility equals a user-defined value.
        '''
        ...


class SameShapeIdBP1D:
    ''' Class hierarchy: `freestyle.types.BinaryPredicate1D` > `SameShapeIdBP1D`
    '''

    def __call__(self, inter1: 'freestyle.types.Interface1D',
                 inter2: 'freestyle.types.Interface1D') -> bool:
        ''' Returns true if inter1 and inter2 belong to the same shape.

        :param inter1: The first Interface1D object.
        :type inter1: 'freestyle.types.Interface1D'
        :param inter2: The second Interface1D object.
        :type inter2: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True or false.
        '''
        ...


class ShapeUP1D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `ShapeUP1D`
    '''

    def __init__(self, first: int, second: int = 0):
        ''' Builds a ShapeUP1D object.

        :param first: The first Id component.
        :type first: int
        :param second: The second Id component.
        :type second: int
        '''
        ...

    def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
        ''' Returns true if the shape to which the Interface1D belongs to has the same `freestyle.types.Id` as the one specified by the user.

        :param inter: An Interface1D object.
        :type inter: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True if Interface1D belongs to the shape of the user-specified Id.
        '''
        ...


class TrueBP1D:
    ''' Class hierarchy: `freestyle.types.BinaryPredicate1D` > `TrueBP1D`
    '''

    def __call__(self, inter1: 'freestyle.types.Interface1D',
                 inter2: 'freestyle.types.Interface1D') -> bool:
        ''' Always returns true.

        :param inter1: The first Interface1D object.
        :type inter1: 'freestyle.types.Interface1D'
        :param inter2: The second Interface1D object.
        :type inter2: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True.
        '''
        ...


class TrueUP0D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate0D` > `TrueUP0D`
    '''

    def __call__(self, it: 'freestyle.types.Interface0DIterator') -> bool:
        ''' Always returns true.

        :param it: An Interface0DIterator object.
        :type it: 'freestyle.types.Interface0DIterator'
        :rtype: bool
        :return: True.
        '''
        ...


class TrueUP1D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `TrueUP1D`
    '''

    def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
        ''' Always returns true.

        :param inter: An Interface1D object.
        :type inter: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True.
        '''
        ...


class ViewMapGradientNormBP1D:
    ''' Class hierarchy: `freestyle.types.BinaryPredicate1D` > `ViewMapGradientNormBP1D`
    '''

    def __init__(self,
                 level: int,
                 integration_type:
                 'freestyle.types.IntegrationType' = 'IntegrationType.MEAN',
                 sampling: float = 2.0):
        ''' Builds a ViewMapGradientNormBP1D object.

        :param level: The level of the pyramid from which the pixel must be read.
        :type level: int
        :param integration_type: The integration method used to compute a single value from a set of values.
        :type integration_type: 'freestyle.types.IntegrationType'
        :param sampling: GetViewMapGradientNormF0D is evaluated at each sample point and the result is obtained by combining the resulting values into a single one, following the method specified by integration_type.
        :type sampling: float
        '''
        ...

    def __call__(self, inter1: 'freestyle.types.Interface1D',
                 inter2: 'freestyle.types.Interface1D') -> bool:
        ''' Returns true if the evaluation of the Gradient norm Function is higher for inter1 than for inter2.

        :param inter1: The first Interface1D object.
        :type inter1: 'freestyle.types.Interface1D'
        :param inter2: The second Interface1D object.
        :type inter2: 'freestyle.types.Interface1D'
        :rtype: bool
        :return: True or false.
        '''
        ...


class WithinImageBoundaryUP1D:
    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `WithinImageBoundaryUP1D`
    '''

    def __init__(self, xmin: float, ymin: float, xmax: float, ymax: float):
        ''' Builds an WithinImageBoundaryUP1D object.

        :param xmin: X lower bound of the image boundary.
        :type xmin: float
        :param ymin: Y lower bound of the image boundary.
        :type ymin: float
        :param xmax: X upper bound of the image boundary.
        :type xmax: float
        :param ymax: Y upper bound of the image boundary.
        :type ymax: float
        '''
        ...

    def __call__(self, inter):
        ''' Returns true if the Interface1D intersects with image boundary.

        '''
        ...


class pyBackTVertexUP0D:
    ''' Check whether an Interface0DIterator references a TVertex and is the one that is hidden (inferred from the context).
    '''

    ...


class pyClosedCurveUP1D:
    ...


class pyDensityFunctorUP1D:
    ...


class pyDensityUP1D:
    ...


class pyDensityVariableSigmaUP1D:
    ...


class pyHighDensityAnisotropyUP1D:
    ...


class pyHighDirectionalViewMapDensityUP1D:
    ...


class pyHighSteerableViewMapDensityUP1D:
    ...


class pyHighViewMapDensityUP1D:
    ...


class pyHighViewMapGradientNormUP1D:
    ...


class pyHigherCurvature2DAngleUP0D:
    ...


class pyHigherLengthUP1D:
    ...


class pyHigherNumberOfTurnsUP1D:
    ...


class pyIsInOccludersListUP1D:
    ...


class pyIsOccludedByIdListUP1D:
    ...


class pyIsOccludedByItselfUP1D:
    ...


class pyIsOccludedByUP1D:
    ...


class pyLengthBP1D:
    ...


class pyLowDirectionalViewMapDensityUP1D:
    ...


class pyLowSteerableViewMapDensityUP1D:
    ...


class pyNFirstUP1D:
    ...


class pyNatureBP1D:
    ...


class pyNatureUP1D:
    ...


class pyParameterUP0D:
    ...


class pyParameterUP0DGoodOne:
    ...


class pyProjectedXBP1D:
    ...


class pyProjectedYBP1D:
    ...


class pyShapeIdListUP1D:
    ...


class pyShapeIdUP1D:
    ...


class pyShuffleBP1D:
    ...


class pySilhouetteFirstBP1D:
    ...


class pyUEqualsUP0D:
    ...


class pyVertexNatureUP0D:
    ...


class pyViewMapGradientNormBP1D:
    ...


class pyZBP1D:
    ...


class pyZDiscontinuityBP1D:
    ...


class pyZSmallerUP1D:
    ...



import sys
import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")


class PHYSICS_PT_rigidbody_constraint_panel:
    bl_context: typing.Any
    bl_region_type: typing.Any
    bl_space_type: typing.Any


class PHYSICS_PT_rigid_body_constraint(PHYSICS_PT_rigidbody_constraint_panel,
                                       bpy_types.Panel, bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_limits(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_limits_angular(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_limits_linear(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_motor(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_motor_angular(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_header(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_motor_linear(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_header(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_objects(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_override_iterations(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_header(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_settings(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_springs(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_springs_angular(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class PHYSICS_PT_rigid_body_constraint_springs_linear(
        PHYSICS_PT_rigidbody_constraint_panel, bpy_types.Panel,
        bpy_types._GenericUI):
    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...



import sys
import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")


class AnnotationDataPanel:
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any

    def draw(self, context):
        ...

    def draw_header(self, context):
        ...

    def draw_layers(self, context, layout, gpd):
        ...


class AnnotationDrawingToolsPanel:
    bl_category: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any

    def draw(self, context):
        ...


class AnnotationOnionSkin:
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any

    def draw(self, context):
        ...

    def draw_header(self, context):
        ...

    def poll(self, context):
        ...


class GPENCIL_MT_cleanup(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GPENCIL_MT_gpencil_draw_delete(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GPENCIL_MT_layer_active(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GPENCIL_MT_layer_mask_menu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GPENCIL_MT_material_active(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GPENCIL_MT_move_to_layer(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GPENCIL_MT_snap(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GPENCIL_MT_snap_pie(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GPENCIL_UL_annotation_layer(bpy_types.UIList, bpy_types._GenericUI):
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw_item(self, _context, layout, _data, item, icon, _active_data,
                  _active_propname, _index):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GPENCIL_UL_layer(bpy_types.UIList, bpy_types._GenericUI):
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw_item(self, _context, layout, _data, item, icon, _active_data,
                  _active_propname, _index):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GPENCIL_UL_masks(bpy_types.UIList, bpy_types._GenericUI):
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw_item(self, _context, layout, _data, item, icon, _active_data,
                  _active_propname, _index):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GREASE_PENCIL_MT_layer_active(bpy_types.Menu, bpy_types._GenericUI):
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GreasePencilBrushFalloff:
    bl_label: typing.Any
    bl_options: typing.Any

    def draw(self, context):
        ...


class GreasePencilDisplayPanel:
    bl_label: typing.Any
    bl_options: typing.Any

    def draw(self, context):
        ...

    def draw_header(self, context):
        ...

    def poll(self, context):
        ...


class GreasePencilFlipTintColors(bpy_types.Operator):
    bl_description: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def as_keywords(self, ignore):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def execute(self, context):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_resolve(self):
        ...

    def poll(self, context):
        ...

    def poll_message_set(self):
        ...

    def pop(self):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class GreasePencilLayerAdjustmentsPanel:
    def draw(self, context):
        ...


class GreasePencilLayerDisplayPanel:
    def draw(self, context):
        ...


class GreasePencilLayerMasksPanel:
    def draw(self, context):
        ...

    def draw_header(self, context):
        ...


class GreasePencilLayerRelationsPanel:
    def draw(self, context):
        ...


class GreasePencilLayerTransformPanel:
    def draw(self, context):
        ...


class GreasePencilMaterialsPanel:
    def draw(self, context):
        ...


class GreasePencilSculptAdvancedPanel:
    def draw(self, context):
        ...


class GreasePencilSimplifyPanel:
    def draw(self, context):
        ...

    def draw_header(self, context):
        ...


class GreasePencilVertexcolorPanel:
    def draw(self, context):
        ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class _ext_global:
    idmap: typing.Any
    module_handle: typing.Any


def check(module_name):
    ...


def disable(module_name, default_set, handle_error):
    ...


def disable_all():
    ...


def enable(module_name, default_set, persistent, handle_error):
    ...


def module_bl_info(mod, info_basis):
    ...


def modules(module_cache, refresh):
    ...


def modules_refresh(module_cache):
    ...


def paths():
    ...


def reset_all(reload_scripts):
    ...



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def bake(override_context: typing.Optional[
        typing.Union[typing.Dict, 'bpy.types.Context']] = None,
         execution_context: typing.Optional[typing.Union[str, int]] = None,
         undo: typing.Optional[bool] = None):
    ''' Bake dynamic paint image sequence surface

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...


def output_toggle(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        output: typing.Optional[typing.Any] = 'A'):
    ''' Add or remove Dynamic Paint output data layer

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param output: Output Toggle
    :type output: typing.Optional[typing.Any]
    '''

    ...


def surface_slot_add(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Add a new Dynamic Paint surface slot

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...


def surface_slot_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Remove the selected surface slot

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...


def type_toggle(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Union[str, int]] = 'CANVAS'):
    ''' Toggle whether given type is active or not

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Type
    :type type: typing.Optional[typing.Union[str, int]]
    '''

    ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


def create_from_info(shader_info: typing.Any) -> typing.Any:
    ''' Create shader from a GPUShaderCreateInfo.

    :param shader_info: GPUShaderCreateInfo
    :type shader_info: typing.Any
    :rtype: typing.Any
    :return: Shader object corresponding to the given name.
    '''

    ...


def from_builtin(shader_name: str, config: str = 'DEFAULT') -> typing.Any:
    ''' Shaders that are embedded in the blender internal code (see :ref:`built-in-shaders`). They all read the uniform ``mat4 ModelViewProjectionMatrix``, which can be edited by the :mod:`gpu.matrix` module. You can also choose a shader configuration that uses clip_planes by setting the ``CLIPPED`` value to the config parameter. Note that in this case you also need to manually set the value of ``mat4 ModelMatrix``.

    :param shader_name: One of the builtin shader names.
    :type shader_name: str
    :param config: - ``DEFAULT`` - ``CLIPPED``
    :type config: str
    :rtype: typing.Any
    :return: Shader object corresponding to the given name.
    '''

    ...


def unbind():
    ''' Unbind the bound shader object.

    '''

    ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class PresetPanel:
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_space_type: typing.Any

    def draw(self, context):
        ...

    def draw_menu(self, layout, text):
        ...

    def draw_panel_header(self, layout):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


def complete(word, namespace, private):
    ...


def complete_indices(word, namespace, obj, base):
    ...


def complete_names(word, namespace):
    ...


def is_dict(obj):
    ...


def is_struct_seq(obj):
    ...



import sys
import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")


class NODE_MT_category_compositor_LAYOUT(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_color(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_color_adjust(bpy_types.Menu,
                                               bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_color_mix(bpy_types.Menu,
                                            bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_filter(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_filter_blur(bpy_types.Menu,
                                              bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_group(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_input(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_input_constant(bpy_types.Menu,
                                                 bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_input_scene(bpy_types.Menu,
                                              bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_keying(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_mask(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_output(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_tracking(bpy_types.Menu,
                                           bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_transform(bpy_types.Menu,
                                            bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_utilities(bpy_types.Menu,
                                            bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_category_compositor_vector(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, _context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...


class NODE_MT_compositor_node_add_all(bpy_types.Menu, bpy_types._GenericUI):
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def append(self, draw_func):
        ...

    def as_pointer(self):
        ...

    def bl_rna_get_subclass(self):
        ...

    def bl_rna_get_subclass_py(self):
        ...

    def draw(self, context):
        ...

    def draw_collapsible(self, context, layout):
        ...

    def draw_preset(self, _context):
        ...

    def driver_add(self):
        ...

    def driver_remove(self):
        ...

    def get(self):
        ...

    def id_properties_clear(self):
        ...

    def id_properties_ensure(self):
        ...

    def id_properties_ui(self):
        ...

    def is_extended(self):
        ...

    def is_property_hidden(self):
        ...

    def is_property_overridable_library(self):
        ...

    def is_property_readonly(self):
        ...

    def is_property_set(self):
        ...

    def items(self):
        ...

    def keyframe_delete(self):
        ...

    def keyframe_insert(self):
        ...

    def keys(self):
        ...

    def path_from_id(self):
        ...

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ...

    def path_resolve(self):
        ...

    def pop(self):
        ...

    def prepend(self, draw_func):
        ...

    def property_overridable_library_set(self):
        ...

    def property_unset(self):
        ...

    def remove(self, draw_func):
        ...

    def type_recast(self):
        ...

    def values(self):
        ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class _TokenizeDataPath:
    data_path: typing.Any


def decompose_data_path(data_path):
    ...


def property_definition_from_data_path(base, data_path):
    ...
